# coding: utf-8

"""
    MMP Metadata

    This is a API for MMP Metadata  # noqa: E501

    The version of the OpenAPI document: 1.0.0-oas3
    Contact: st116848@stud.uni-stuttgart.de.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class TraceArtifacts(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'artifact_id': 'str',
        'name': 'str',
        'run_ids': 'list[str]'
    }

    attribute_map = {
        'artifact_id': 'artifactId',
        'name': 'name',
        'run_ids': 'runIds'
    }

    def __init__(self, artifact_id=None, name=None, run_ids=None):  # noqa: E501
        """TraceArtifacts - a model defined in OpenAPI"""  # noqa: E501

        self._artifact_id = None
        self._name = None
        self._run_ids = None
        self.discriminator = None

        if artifact_id is not None:
            self.artifact_id = artifact_id
        if name is not None:
            self.name = name
        if run_ids is not None:
            self.run_ids = run_ids

    @property
    def artifact_id(self):
        """Gets the artifact_id of this TraceArtifacts.  # noqa: E501


        :return: The artifact_id of this TraceArtifacts.  # noqa: E501
        :rtype: str
        """
        return self._artifact_id

    @artifact_id.setter
    def artifact_id(self, artifact_id):
        """Sets the artifact_id of this TraceArtifacts.


        :param artifact_id: The artifact_id of this TraceArtifacts.  # noqa: E501
        :type: str
        """

        self._artifact_id = artifact_id

    @property
    def name(self):
        """Gets the name of this TraceArtifacts.  # noqa: E501


        :return: The name of this TraceArtifacts.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TraceArtifacts.


        :param name: The name of this TraceArtifacts.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def run_ids(self):
        """Gets the run_ids of this TraceArtifacts.  # noqa: E501


        :return: The run_ids of this TraceArtifacts.  # noqa: E501
        :rtype: list[str]
        """
        return self._run_ids

    @run_ids.setter
    def run_ids(self, run_ids):
        """Sets the run_ids of this TraceArtifacts.


        :param run_ids: The run_ids of this TraceArtifacts.  # noqa: E501
        :type: list[str]
        """

        self._run_ids = run_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TraceArtifacts):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
