# coding: utf-8

"""
    MMP Metadata

    This is a API for MMP Metadata  # noqa: E501

    The version of the OpenAPI document: 1.0.0-oas3
    Contact: st116848@stud.uni-stuttgart.de.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mmp_metadata_client
from mmp_metadata_client.models.trace_execution_types import TraceExecutionTypes  # noqa: E501
from mmp_metadata_client.rest import ApiException


class TestTraceExecutionTypes(unittest.TestCase):
    """TraceExecutionTypes unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTraceExecutionTypes(self):
        """Test TraceExecutionTypes"""
        # FIXME: construct object with mandatory attributes with example values
        # model = mmp_metadata_client.models.trace_execution_types.TraceExecutionTypes()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
