# coding: utf-8

"""
    MMP Metadata

    This is a API for MMP Metadata  # noqa: E501

    The version of the OpenAPI document: 1.0.0-oas3
    Contact: st116848@stud.uni-stuttgart.de.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import openapi_client
from openapi_client.api.execution_api import ExecutionApi  # noqa: E501
from openapi_client.rest import ApiException


class TestExecutionApi(unittest.TestCase):
    """ExecutionApi unit test stubs"""

    def setUp(self):
        self.api = openapi_client.api.execution_api.ExecutionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_experiments_experiment_runs_run_executions_get(self):
        """Test case for experiments_experiment_runs_run_executions_get

        list of executions  # noqa: E501
        """
        pass

    def test_experiments_experiment_runs_run_executions_post(self):
        """Test case for experiments_experiment_runs_run_executions_post

        adds an execution  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
