# coding: utf-8

"""
    MMP Metadata

    This is a API for MMP Metadata  # noqa: E501

    The version of the OpenAPI document: 1.0.0-oas3
    Contact: st116848@stud.uni-stuttgart.de.com
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "mmp-metadata"
VERSION = "1.1.3"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="MMP Metadata",
    author="Matthias Popp",
    author_email="st116848@stud.uni-stuttgart.de.com",
    url="https://www.ipvs.uni-stuttgart.d",
    keywords=["OpenAPI", "OpenAPI-Generator", "MMP Metadata"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    This is a API for MMP Metadata  # noqa: E501
    """
)
